/* 故障报修
 * @Author: Li Hanlin
 * @Date: 2022-11-25 09:18:03
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2022-11-28 10:50:21
 */

import * as React from 'react';
import { useState, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { doFetch } from '@/utils/doFetch';

function Failure(props) {
  const actionRef = useRef(),
    formRef = useRef(),
    [drawer, setdrawer] = useState({
      visible: false,
    }),
    [activeTabKey, onTabChange] = useState('1');

  const urlParams = {
    detail: '/repair/umFailureRepair/queryById',
    save: '/repair/umFailureRepair/save',
    remove: '/repair/umFailureRepair/deleteById',
    list_unfinished: '/repair/umFailureRepair/queryNoFinishList',
    list_finished: '/repair/umFailureRepair/queryFinishList',
  };
  const detail = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          type: 'link',
          onClick: () => {
            setdrawer((s) => ({
              ...s,
              visible: true,
              item: row,
              title: '详情',
              val: 'detail',
              title: row.userName + '的详细信息',
            }));
          },
        }}
      >
        详情
      </PremButton>
    );
  };

  const remove = (text, row, _, action) => {
    return (
      <PremButton
        pop={{
          title: '是否删除该用户?',
          okText: '确认',
          cancelText: '取消',
          onConfirm: () => {},
        }}
        btn={{
          size: 'small',
          type: 'danger',
        }}
      >
        删除
      </PremButton>
    );
  };

  const columns_add = [
    {
      title: '选择设备',
      dataIndex: 'equipmentId',
      key: 'equipmentId',
      valueType: 'select',
      options: { path: '/asset/equipment/selection/user/shop', params: {} },
    },
    {
      title: '是否停机',
      dataIndex: 'isShutdown',
      key: 'isShutdown',
      valueType: 'radio',
      options: [
        {
          label: '是',
          value: 1,
        },
        {
          label: '否',
          value: 2,
        },
      ],
    },
    {
      title: '故障类型',
      dataIndex: 'faultSettingId',
      valueType: 'select',
      key: 'faultSettingId',
      options: {
        path: '/repair/umFaultSetting/selected/queryList',
        linkParams: {
          equipmentId: '',
        },
      },
    },
    {
      title: '故障名称',
      dataIndex: 'faultDetailId',
      valueType: 'select',
      key: 'faultDetailId',
      options: {
        path: '/repair/umFaultSettingDetail/selected/queryList',
        linkParams: {
          faultSettingId: '',
        },
      },
    },
    {
      title: '故障描述',
      valueType: 'textarea',
      dataIndex: 'faultDescription',
      key: 'faultDescription',
    },
    {
      title: '故障图片',
      dataIndex: 'pictureId',
      key: 'pictureId',
      valueType: 'uploadImage',
      fieldProps: {
        limit: 2,
      },
    },
  ];
  const columns = useMemo(() => {
    let defcolumn = getcolumns(setdrawer);
    return defcolumn.concat({
      title: '操作',
      valueType: 'option',
      width: 150,
      render: (text, row, _, action) => [
        detail(text, row, _, action),
        remove(text, row, _, action),
      ],
    });
  }, []);

  return (
    <div style={{ position: 'relative' }}>
      <AutoTable
        pagetitle={<h3 className="page-title">故障报修</h3>}
        columns={columns}
        actionRef={actionRef}
        pageextra={'add'}
        resizeable={true}
        path={activeTabKey == '1' ? urlParams.list_unfinished : urlParams.list_finished}
        tabList={[
          {
            tab: '未完成',
            key: '1',
          },
          {
            tab: '已完成',
            key: '2',
          },
        ]}
        addconfig={{
          // access: 'sysDepartment_save',
          btn: {
            disabled: false,
            type: 'primary',
            onClick: () => {
              setdrawer((s) => ({
                ...s,
                visible: true,
                item: {
                  isShutdown: 1,
                },
                title: '新增',
                val: 'add',
                onFinish: async (vals) => {
                  console.log(vals);
                  let params = {
                    ...vals,
                  };
                  let res = await doFetch({
                    url: urlParams.save,
                    params,
                  });
                  if (res.code === '0000') {
                    message.success('新增保修单成功！');
                    setdrawer((s) => ({
                      ...s,
                      visible: false,
                    }));
                    actionRef.current.reload();
                  }
                },
              }));
            },
          },
        }}
      />

      <DrawerPro
        fields={drawer?.val == 'add' ? columns_add : columns}
        // detailpath="/ngic-auth/sysUser/query/detail"
        params={{ id: drawer?.item?.id }}
        formRef={formRef}
        placement="right"
        onClose={() => {
          setdrawer((s) => ({
            ...s,
            visible: false,
          }));
        }}
        {...drawer}
      />
    </div>
  );
}

export default Failure;
